MarkerLocator

Qualified name: n_fold_edge.marker_locator.MarkerLocator

class MarkerLocator(order, kernel_size=55, scale_factor=1000)[source]

Bases: object

Locate a marker in an image.

Parameters:
  • order (int) – The order type of the marker to locate.

  • kernel_size (int) – Kernel size to use for detecting the marker.

  • scale_factor (float) – Scale factor to use for detecting the marker.

Methods

apply_convolution_with_complex_kernel

Get the response from applying the convolution of a complex kernel on an image.

locate_marker

Locate the marker with in the frame.

apply_convolution_with_complex_kernel(frame)[source]

Get the response from applying the convolution of a complex kernel on an image.

Parameters:

frame (ndarray) – Image or frame of a marker.

Returns:

response – Result of applying the convolution of a complex kernel.

Return type:

ndarray

locate_marker(frame)[source]

Locate the marker with in the frame.

Parameters:

frame (ndarray) – A frame or image with the marker to locate.

Return type:

MarkerPose