MarkerTracker¶
Qualified name: n_fold_edge.marker_tracker.MarkerTracker
- class MarkerTracker(marker_locators, show_video=False)[source]¶
Bases:
objectTrack markers in video file or video stream.
- Parameters:
marker_locators (MarkerLocator | Sequence[MarkerLocator]) – One or more MarkerLocator instances for the markers to track.
show_video (bool) – Whether to show the video as the markers are being tracked.
Methods
Start tracking of markers in video.
- track(video, save_video_path=None, save_csv_path=None)[source]¶
Start tracking of markers in video.
- Parameters:
video (Path | int) – Path to a video or a id if webcam is used.
save_video_path (Path | None) – Path to save video with detected markers drawn on if desired.
save_csv_path (Path | None) – Path to save found marker location in csv format if desired.
- Return type:
None