MarkerLocator¶
Qualified name: n_fold_edge.marker_locator.MarkerLocator
- class MarkerLocator(order, kernel_size=55, scale_factor=1000)[source]¶
Bases:
objectLocate a marker in an image.
- Parameters:
Methods
Get the response from applying the convolution of a complex kernel on an image.
Locate the marker with in the frame.
- apply_convolution_with_complex_kernel(frame)[source]¶
Get the response from applying the convolution of a complex kernel on an image.
- Parameters:
frame (ndarray) – Image or frame of a marker.
- Returns:
response – Result of applying the convolution of a complex kernel.
- Return type:
ndarray